@@ -8,7 +8,7 @@ check connectivity!
 
 import board
 import busio
-import pulseio
+import pwmio
 import adafruit_avrprog
 
 spi = busio.SPI(board.SCK, board.MOSI, board.MISO)
@@ -17,7 +17,7 @@ avrprog.init(spi, board.D5)
 
 # pylint: disable-msg=no-member
 # we can generate an 6 MHz clock for driving bare chips too!
-clock_pwm = pulseio.PWMOut(board.D9, frequency=6000000, duty_cycle=65536 // 2)
+clock_pwm = pwmio.PWMOut(board.D9, frequency=6000000, duty_cycle=65536 // 2)
 # pylint: enable-msg=no-member
 
 avrprog.begin()
